==> haskell-hookup-0.8-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-16nwMYSwYtu99sSvrKk5We
key:                  hookup-0.8-16nwMYSwYtu99sSvrKk5We
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  2aca6bf464a74b13b70638f10292f5ee
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-16nwMYSwYtu99sSvrKk5We
depends:
    HsOpenSSL-0.11.7.9-7rM3XcO073UGlPooPcpWFC
    HsOpenSSL-x509-system-0.1.0.4-4RPTZmLFBlJ3QI7wLI6FGw
    async-2.2.5-LqkzH7L8HyYHud0cQFVYjz
    attoparsec-0.14.4-a7MjceIUMFKMmgfXk7t7H base-4.17.2.1
    bytestring-0.11.5.3 network-3.1.4.0-9ZkyLgutzTZFWrHs4BgIgX
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hookup-0.8-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hookup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-7e624D1BilDCzbnPhv2OoH
key:                  hookup-0.8-7e624D1BilDCzbnPhv2OoH
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  79b8deddb91d9af8f0f1f78337d20c98
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-7e624D1BilDCzbnPhv2OoH
depends:
    HsOpenSSL-0.11.7.9-Iw1EFh3wZS8LcoBYdzqrEa
    HsOpenSSL-x509-system-0.1.0.4-5Pi4rmqS9jd4wyfyl3zIGd
    async-2.2.5-BcqMz9kSLpQJiwvDzQjiwa
    attoparsec-0.14.4-FKpKWqwLteZDlwxf33yCFk base-4.17.2.1
    bytestring-0.11.5.3 network-3.1.4.0-Aot7Hsnd3no7HIoU7vrrpP
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
